@@ -5,7 +5,6 @@ from .models import IdentityKey, SignedPreKey, PreKey, EncryptingSenderKey, Decr
 from django.db.models import Q
 from firebase_admin import db
 from django.conf import settings
-from knox.crypto import hash_token
 
 DEFAULT_APP = settings.DEFAULT_APP
 FIREBASE_REF = settings.FIREBASE_REF
@@ -20,7 +19,7 @@ class StickProtocol():
         self.Group = GroupModel
 
 
-    def save_pre_key_bundle(self, request, user):
+    def process_pre_key_bundle(self, request, user):
         """
         A user must upload their PreKeyBundle at registration time. Before uploading their PreKeyBundle, they need to verify
         their phone number, and get their LimitedAccessToken.
@@ -43,13 +42,14 @@ class StickProtocol():
         user.finishedRegistration = True
         user.save()
         Party.objects.create(user=user)
-        LimitedAccessToken.objects.get(phone=request.data['phone']).delete()
+        # LimitedAccessToken.objects.get(phone=request.data['phone']).delete()
 
 
 
-    def save_pre_keys(self, request):
+    def process_pre_keys(self, request):
         """
         A user would need to refill their PreKeys on the server every while whenever it goes below a certain N value.
+        This method save preKeys and updates the nextPreKeyId value
         """
         user = request.user
         preKeys = request.data['preKeys']
@@ -61,7 +61,7 @@ class StickProtocol():
 
 
 
-    def fetch_pre_key_bundle(self, request, user_id):
+    def get_pre_key_bundle(self, request, user_id):
         """
         The following get method is used to fetch the PreKeyBundle of user to create a pairwise signal session. The request must contain
         a boolean `isSticky` to know whether this bundle would be used to communicate a SenderKey or not. If it will be used to
@@ -101,7 +101,7 @@ class StickProtocol():
 
 
 
-    def fetch_pre_key_bundles(self, request, users_id):
+    def get_pre_key_bundles(self, request, users_id):
         """
         Similar to the above method, but fetches PreKeyBundles of several users at once. This method allows a user to
         communicate their SenderKey to multiple members of a party at once.
@@ -152,7 +152,7 @@ class StickProtocol():
 
 
 
-    def fetch_sender_key(self, request):
+    def get_sender_key(self, request):
         """
         This method is used to fetch the SenderKey of a stickySession.
         The body should contain the following fields:
@@ -237,7 +237,7 @@ class StickProtocol():
 
 
 
-    def fetch_standard_sender_keys(self, request, group):
+    def get_standard_sender_keys(self, request, group):
         """
         This method is used to fetch the standard session sender keys of a group.
         """
@@ -257,7 +257,7 @@ class StickProtocol():
 
 
 
-    def fetch_uploaded_sender_keys(self, request):
+    def get_uploaded_sender_keys(self, request):
         """
         Before a user makes an upload they need to know which stickId to use (whether the current sticky session has expired).
         Also, they need to know which members of the target party does not have their SenderKey for that sticky session.
@@ -387,7 +387,7 @@ class StickProtocol():
         return responseDict
 
 
-    def save_sender_key(self, request):
+    def process_sender_key(self, request):
         """
         This method is used to save a SenderKey of a sticky session for a user. Typically used when a user
         receives a `PendingKey` request.
@@ -402,7 +402,7 @@ class StickProtocol():
 
 
 
-    def save_sender_keys(self, request):
+    def process_sender_keys(self, request):
         """
         This method is used to save SenderKeys of multiple users at once. Before making an upload, and after
         the user has made a request to get the UploadedSenderKeys, and now knows which users does not have SenderKeys for
@@ -430,7 +430,7 @@ class StickProtocol():
             request.user.just_added_groups.remove(request.data["group_id"])
 
 
-    def save_standard_sender_keys(self, request):
+    def process_standard_sender_keys(self, request):
         """
         This method is used to upload the SenderKeys of a standard session.
         """
@@ -441,7 +441,7 @@ class StickProtocol():
                                                forOneTimeId=oneTimeId, ofOneTimeId=request.user.oneTimeId)
 
 
-    def verify_password_and_fetch_keys(self, request, user):
+    def verify_password_and_get_keys(self, request, user):
         """
         This Login method should be called after the user have verified their phone number and got their LimitedAccessToken.
         As a 2FA mechanism, the user need to provide their password. If the password is correct, return to the user their keys:
@@ -487,14 +487,14 @@ class StickProtocol():
             bundle['senderKeys'] = senderKeys
             user.oneTimeId = uuid.uuid4()
             user.save()
-            LimitedAccessToken.objects.get(phone=request.data['phone']).delete()
+            # LimitedAccessToken.objects.get(phone=request.data['phone']).delete()
             return {"bundle": bundle, "success": True}
         else:
             return Response({"success": False})
 
 
 
-    # def fetch_one_time_id(self, request):
+    # def get_one_time_id(self, request):
     #     """
     #     This method is used to fetch the OneTimeId of a user.
     #     An example of usage is when entering a chat room a user need to know
